/*!
 ************************************************************************
 * \file adaptive_quantization.h
 *
 * \brief
 *    adaptive quantization matrix selection routines
 *
 * \author
 *  Akiyuki Tanizawa       <akiyuki.tanizawa@toshiba.co.jp>           \n
 *  Takeshi Chujoh         <takeshi.chujoh@toshiba.co.jp>             \n
 *
 * This software may be used for research purposes only.
 * TOSHIBA would also appreciate that any technical report, conference or
 * journal paper which uses the software includes one of the following references:
 *    - A. Tanizawa, T. Chujoh, "Adaptive Quantization Matrix Selection",
 *                              VCEG contribution D.266, Geneva, November 2006.
 *    - A. Tanizawa, T. Chujoh, "Simulation results of AQMS on KTA software",
 *                              VCEG contribution VCEG-AC07, Klagenfurt, July 2006.
 *    - A. Tanizawa, T. Chujoh, "Adaptive Quantization Matrix Selection on KTA software",
 *                              VCEG contribution VCEG-AD06, Hangzhou, Oct. 2006.
 *    - A. Tanizawa, T. Chujoh, "Simulation results of AQMS on KTA software version 1.3",
 *                              VCEG contribution VCEG-AF08, San Jose, April 2007.
 *    - A. Tanizawa, T. Chujoh, T. Yamakage, 
 *                              "Encoding complexity reduction of AQMS",
 *                              VCEG contribution C.403, Geneve, April 2008.
 ************************************************************************
 */

#ifndef _ADAPTIVE_QUANTIZATION_H_
#define _ADAPTIVE_QUANTIZATION_H_

#include "global.h"
#include "mbuffer.h"

#ifdef ADAPTIVE_QUANTIZATION
//!------for header.c
void CreateModelingMatrix(int type);

//!------for block.c
void AssignQuantParamForAQMS(pic_parameter_set_rbsp_t* pps);
void CalculateQuantParamForAQMS();

//!------for parset.c
void SetAutoScalingListData(int InternalFlag);
void CreateScalingList4x4(int pT, int pA, int pB, int InternalFlag);
void CreateScalingList8x8(int pT, int pA, int pB, int InternalFlag);

//!------for macroblock.c
void CalculateQuant8ParamForAQMS();
#endif
#endif //_ADAPTIVE_QUANTIZATION_H_

